@@ -1,6 +1,6 @@
 """File with version and history information."""
 
-__version__ = '1.0.0'
+__version__ = '1.0.2'
 
 """
 History Information:
@@ -8,4 +8,6 @@ History Information:
     First Version
 1.0.1
     Removed tests folder from pip
+1.0.2
+    Fixed documentation
 """
